ControlProjection
=================

.. automodule:: psyneulink.core.components.projections.modulatory.controlprojection
   :members:
   :private-members:
   :exclude-members: random, execute, Parameters
